Main - Alpha Documentation

Skip to content

# Introduction

The api system is completely based on Flask and compatible with it. You could use Flask inside Alpha system without any issue.

## Launch

To start the api execute the `api.py` file

    python api.py

Note

set `ALPHA_CONF` environment parameter is you want to set the environment.

Verify the deployment by navigating to your server address in your preferred browser:

    127.0.0.1:<port>

## How to use

Your could import it using simply from the utils:

    from alphaz.utils.api import api

or from the core if you are using it

    from core import core, API

> api / API is the equivalent for app in Flask framework.